@@ -5,7 +5,7 @@ package GFX::Enhancer::ImageRepresentation;
 sub new {
 	my ($class) = @_;
 
-	my $self = { points => (), }; ### points are byte indexes in rect img
+	my $self = { width => 0, height => 0, points => (), }; ### points are PNGRGBAs 
 					### they have colour other than white
 
 	$class = ref($class) || $class;
@@ -16,15 +16,19 @@ sub new {
 ### public methods
 
 sub scan_in_points_of_png_image_file {
+### points have a colour
 	my ($self, $filename) = @_;
 
 	my $reader = GFX::Enhancer::PNGReader->new;
 	$reader->read_in_byte_array($filename);
+
+	$self->{width} = $reader->{width};	
+	$self->{height} = $reader->{height};	
 	
-	for (my $i = 0; $i < $reader->{length}; $i+4) {
-		my $rgba = GFX::Enhancer::PNGRGBA->new($reader->get_byte_interval($i, $i+4));
+	for (my $i = 0; $i < $reader->{length}; $i+=4) {
+		my $rgba = GFX::Enhancer::PNGRGBA->new($i, $reader->get_byte_interval($i, $i+4)); ### NOTE: ctor takes index here
 		if (($rgba->red | $rgba->green | $rgba->blue) > 0) {
-			push($self->{points}, $i);
+			push($self->{points}, $rgba);
 		}
 	}  
 		 
